Transition Models
=================

.. automodule:: stonesoup.models.transition
    :no-members:

.. automodule:: stonesoup.models.transition.base
    :show-inheritance:

Linear
------
.. automodule:: stonesoup.models.transition.linear
    :show-inheritance:
    :inherited-members:
